(caveats)=
# Caveats

[![Image](https://github.com/user-attachments/assets/6e8ea47c-20fd-4d37-9245-76e6cb7306ae){w=480px}][BuzzFeed]

_It's like the government is being run by BuzzFeed. [It's ridiculous!][BuzzFeed]._

## Development

To protect your confidential information on GitHub, it is not recommended
to run CI workflow jobs for Rapporto on an organization including private
repositories. On a misconfiguration of GitHub secrets, this may reveal such
information. The same holds true with the other subsystems that access APIs
of Opsgenie, Slack, and others.

## Don't Panic

![Image](https://github.com/user-attachments/assets/bb775ff8-95dd-47f9-a593-37a04757e4d8)

## Guardrails

Rapporto provides much information on your fingertips suitable to haunt
humans, by harassing them on any of the items emitted by this program,
in one way or another. Don't do that.

> In addition to, not invalidating the existing sections in Rapporto's
> [license document], and with a strong emphasis like on topics about
> Disclaimer of Warranties and Limitation of Liabilities, THIS SOFTWARE
> MUST NOT BE USED TO JUDGE, RANK, OR TRACK PEOPLE, OR TO CREATE ANY
> KINDS OF DOSSIERS ABOUT THEM, WHERE SUCH METRICS OR RANKINGS CAN
> BE DERIVED FROM, WHICH COULD BE USED BY OTHERS FOR SIMILAR PURPOSES,
> INCLUDING MACHINES.

## Q & A

> Q: What's the difference between a controller and a terrorist?
> <br>
> A: A terrorist at least has sympathisers.


[BuzzFeed]: https://www.youtube.com/watch?v=4xGUlG5Ck6c&t=105s
[license document]: https://github.com/tech-writing/rapporto/blob/main/LICENSE
